==> arquillian-container-test-impl-base-1.0.4.Final-sources.jar: org/jboss/arquillian/container/test/impl/enricher/resource/InitialContextProvider.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.container.test.impl.enricher.resource;

import java.lang.annotation.Annotation;

import javax.naming.Context;
import javax.naming.InitialContext;

import org.jboss.arquillian.core.api.Instance;
import org.jboss.arquillian.core.api.annotation.Inject;
import org.jboss.arquillian.test.api.ArquillianResource;

/**
 * InitialContextProvider
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class InitialContextProvider extends OperatesOnDeploymentAwareProvider
{
   @Inject
   private Instance<Context> initialContext;

   @Override
   public Object doLookup(ArquillianResource resource, Annotation... qualifiers)
   {
      return initialContext.get();
   }

   @Override
   public boolean canProvide(Class<?> type)
   {
      return Context.class.isAssignableFrom(type) || InitialContext.class.isAssignableFrom(type);
   }
}

==> arquillian-container-test-impl-base-1.1.12.Final-sources.jar: org/jboss/arquillian/container/test/impl/enricher/resource/InitialContextProvider.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.container.test.impl.enricher.resource;

import java.lang.annotation.Annotation;

import javax.naming.Context;
import javax.naming.InitialContext;

import org.jboss.arquillian.core.api.Instance;
import org.jboss.arquillian.core.api.annotation.Inject;
import org.jboss.arquillian.test.api.ArquillianResource;

/**
 * InitialContextProvider
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class InitialContextProvider extends OperatesOnDeploymentAwareProvider
{
   @Inject
   private Instance<Context> initialContext;

   @Override
   public Object doLookup(ArquillianResource resource, Annotation... qualifiers)
   {
      return initialContext.get();
   }

   @Override
   public boolean canProvide(Class<?> type)
   {
      return type.isAssignableFrom(Context.class) || type.isAssignableFrom(InitialContext.class);
   }
}
